@@ -6,10 +6,9 @@
 #' The test is only meaningful for concepts modeled as composites.
 #'
 #' If more than two groups are to be compared issues related to multiple testing
-#' should be taken into account. Future versions of the package will include
-#' appropriate corrections.
+#' should be taken into account.
 #' 
-#' Moreover, second-order models are not supported yet.
+#' Models containing second-order constructs are not supported yet.
 #'
 #' The number of permutation runs defaults to `args_default()$.R` for performance reasons.
 #' According to \insertCite{Henseler2016;textual}{cSEM} the number of permutations should 
@@ -18,6 +17,7 @@
 #' @usage testMICOM(
 #'  .object               = NULL,
 #'  .alpha                = 0.05,
+#'  .approach_p_adjust    = "none",
 #'  .handle_inadmissibles = c("drop", "ignore", "replace"), 
 #'  .R                    = 499,
 #'  .seed                 = NULL,
@@ -47,7 +47,7 @@
 testMICOM <- function(
   .object               = NULL,
   .alpha                = 0.05,
-  # .approach_p_adjust    = "none",
+  .approach_p_adjust    = "none",
   .handle_inadmissibles = c("drop", "ignore", "replace"),
   .R                    = 499,
   .seed                 = NULL,
@@ -72,7 +72,6 @@ testMICOM <- function(
     
   } else {
     ### Checks and errors ========================================================
-    
     ## Check if at least two groups are present
     if(!inherits(.object, "cSEMResults_multi")) {
       stop2(
@@ -95,22 +94,29 @@ testMICOM <- function(
         "Test results are only meaningful for composite models!")
     }
     
-    if(.verbose & length(.object) > 2) {
-      warning2(
-        "The following warning occured in the `testMICOM()` function:\n",
-        "Comparing more than two groups inflates the familywise error rate.\n",
-        "Interpret statistical significance with caution.\n",
-        "Future versions of the package will likely include appropriate correction options.")
-    }
+    # if(.verbose & length(.object) > 2) {
+    #   warning2(
+    #     "The following warning occured in the `testMICOM()` function:\n",
+    #     "Comparing more than two groups inflates the familywise error rate.\n",
+    #     "Interpret statistical significance with caution.\n",
+    #     "Future versions of the package will likely include appropriate correction options.")
+    # }
     
     # if(.approach_p_adjust != 'none'){
     #   stop2("P-value adjustment to control the familywise error rate not supported yet.")
     # }
     
     ### Preparation ==============================================================
-    ## Get pooled data (potentially unstandardized) and remove id column
-    X <- as.matrix(.object[[1]]$Information$Data_pooled)
-    # X <- as.matrix(X[, -which(colnames(X) == .object[[1]]$Information$Arguments$.id)])
+    ## Get pooled data (potentially unstandardized) 
+    X <- .object[[1]]$Information$Data_pooled
+    X <- processData(X, .model = .object[[1]]$Information$Model)
+    
+    ## Remove id column: 
+    # If .id has been supplied, delete column with the id name otherwise skip
+    # if(!is.null(.object[[1]]$Information$Arguments$.id)) {
+    #   X <- X[, -which(colnames(X) == .object[[1]]$Information$Arguments$.id)]
+    # }
+    X <- as.matrix(X)
     
     # Collect initial arguments (from the first object, but could be any other)
     arguments <- .object[[1]]$Information$Arguments
@@ -253,16 +259,45 @@ testMICOM <- function(
     
     # Order alphas (decreasing order)
     .alpha <- .alpha[order(.alpha)]
-    critical_values_step2 <- lapply(lapply(temp, as.matrix), matrixStats::colQuantiles, 
-                                    probs = .alpha, drop = FALSE) # lower quantile needed, hence 
+    # critical_values_step2 <- lapply(lapply(temp, as.matrix), matrixStats::colQuantiles, 
+    #                                 probs = .alpha, drop = FALSE) # lower quantile needed, hence 
     # alpha and not 1 - alpha
     
-    ## Decision
-    decision <- mapply(function(x, y) x > y, # dont reject (TRUE) if the value of 
-                       x = c,                # the teststat is larger than the critical value
-                       y = critical_values_step2,
-                       SIMPLIFY = FALSE)
+    # Calculate the p-value for the second step of MICOM
+    pvalue_step2<- lapply(1:length(temp), function(x) {
+      # Share of values above the positive test statistic
+      # temp contains a list of the reference distributions
+      rowMeans(t(temp[[x]]) <= c[[x]]) 
+    })
+    names(pvalue_step2) <- names(temp)
     
+    padjusted_step2 <- lapply(as.list(.approach_p_adjust), function(x){
+      # Select p_values per composite and only adjust those
+      temp <- purrr::transpose(pvalue_step2)
+      temp1 <- lapply(temp,function(comp){
+        stats::p.adjust(unlist(comp),method = x)
+      })
+      # sort them back
+      lapply(purrr::transpose(temp1),unlist)
+    })
+    names(padjusted_step2) <- .approach_p_adjust
+
+    
+    # Decision 
+    # TRUE = p-value > alpha --> not reject
+    # FALSE = sufficient evidence against the H0 --> reject
+    decision_step2 <- lapply(padjusted_step2, function(adjust_approach){ # over the different p adjustments
+      temp <- lapply(.alpha, function(alpha){# over the different significance levels
+        lapply(adjust_approach,function(group_comp){# over the different group comparisons
+          # check whether the p values are larger than a certain alpha
+          as.matrix(group_comp > alpha,ncol=1)
+        })
+      })
+      names(temp) <- paste0(.alpha*100, "%")
+      temp
+    })
+    # TRUE do not reject; FALSE: reject
+
     ### Step 3 - Equal mean values and variances==================================
     # Update arguments
     arguments[[".data"]] <- X
@@ -330,45 +365,128 @@ testMICOM <- function(
     # dataset
     mv_o <- lapply(mv, function(x) lapply(x, function(y) y[1, ]))
     
+    # Test the means
+    teststat_mean <- mv_o$Mean
+    
+    # Collect reference distribution
+    ref_dist_mean <- lapply(mv$Mean,function(x){x[-1,,drop=FALSE]}) 
+    # Calculate p-value
+    pvalue_mean <- lapply(1:length(ref_dist_mean), function(x) {
+      # Share of values above the positive test statistic
+      rowMeans(t(ref_dist_mean[[x]]) > abs(teststat_mean[[x]])) +
+        # share of values of the reference distribution below the negative test statistic 
+        rowMeans(t(ref_dist_mean[[x]]) < (-abs(teststat_mean[[x]])))
+    })
+    names(pvalue_mean) <- names(ref_dist_mean)
+    # Adjust p-values: Correct pvalues by the number of groups
+    padjusted_mean <- lapply(as.list(.approach_p_adjust), function(x){
+      # Select p_values per composite and only adjust those
+      temp <- purrr::transpose(pvalue_mean)
+      # pAdjust needs to now how many p-values there are to do a proper adjustment
+      temp1 <- lapply(temp,function(comp){
+        stats::p.adjust(unlist(comp),method = x)
+      })
+      # sort them back
+      lapply(purrr::transpose(temp1),unlist)
+    })
+    names(padjusted_mean) <- .approach_p_adjust
+    
+    # Make decision
+    decision_mean <- lapply(padjusted_mean, function(adjust_approach){ # over the different p adjustments
+      temp <- lapply(.alpha, function(alpha){# over the different significance levels
+        lapply(adjust_approach,function(group_comp){# over the different group comparisons
+          # check whether the p values are larger than a certain alpha
+          as.matrix(group_comp > alpha,ncol=1)
+        })
+      })
+      names(temp) <- paste0(.alpha*100, "%")
+      temp
+    })
+    # TRUE: do not reject; FALSE: reject
+    
+    
+    # Test the variance
+    teststat_var <- mv_o$Var
+    # Collect reference distribution
+    ref_dist_var <-  lapply(mv$Var,function(x){x[-1,,drop=FALSE]})
+    # Calculate p-value
+    pvalue_var <- lapply(1:length(ref_dist_var), function(x) {
+      # Share of values above the positive test statistic
+      rowMeans(t(ref_dist_var[[x]]) > abs(teststat_var[[x]])) +
+        # share of values of the reference distribution below the negative test statistic 
+        rowMeans(t(ref_dist_var[[x]]) < (-abs(teststat_var[[x]])))
+    })
+    
+    names(pvalue_var) <- names(ref_dist_var)
+    
+    # Adjust p-values, e.g., Bonferroni: Multiply all p-values by the number of comparisons
+    padjusted_var <- lapply(as.list(.approach_p_adjust), function(x){
+      # Select p_values per composite and only adjust those
+      temp <- purrr::transpose(pvalue_var)
+      # pAdjust needs to now how many p-values there are to do a proper adjustment
+      temp1 <- lapply(temp,function(comp){
+        stats::p.adjust(unlist(comp),method = x)
+      })
+      # sort them back
+      lapply(purrr::transpose(temp1),unlist)
+    })
+    
+    names(padjusted_var) <- .approach_p_adjust
+    # Make decision
+    decision_var <- lapply(padjusted_var, function(adjust_approach){ # over the different p adjustments
+      temp <- lapply(.alpha, function(alpha){# over the different significance levels
+        lapply(adjust_approach,function(group_comp){# over the different group comparisons
+          # check whether the p values are larger than a certain alpha
+          as.matrix(group_comp > alpha,ncol=1)
+        })
+      })
+      names(temp) <- paste0(.alpha*100, "%")
+      temp
+    })
+    
+    
+    
     ## Compute quantiles/critical values
-    probs <- c()
-    for(i in seq_along(.alpha)) { 
-      probs <- c(probs, .alpha[i]/2, 1 - .alpha[i]/2) 
-    }
-    
-    critical_values_step3 <- lapply(mv, function(x) lapply(x, function(y) y[-1, ])) %>% 
-      lapply(function(x) lapply(x, function(y) matrixStats::colQuantiles(y, probs =  probs, drop = FALSE)))
-    
-    ## Compare critical value and teststatistic
-    # For Mean
-    decision_m <- mapply(function(x, y) abs(x) < y[, seq(2, length(.alpha)*2, by = 2), drop = FALSE],
-                         x = mv_o[[1]],
-                         y = critical_values_step3[[1]],
-                         SIMPLIFY = FALSE)
-    # For Var
-    decision_v <- mapply(function(x, y) abs(x) < y[, seq(2, length(.alpha)*2, by = 2), drop = FALSE],
-                         x = mv_o[[2]],
-                         y = critical_values_step3[[2]],
-                         SIMPLIFY = FALSE)
+    # probs <- c()
+    # for(i in seq_along(.alpha)) { 
+    #   probs <- c(probs, .alpha[i]/2, 1 - .alpha[i]/2) 
+    # }
+    # 
+
+
+    # critical_values_step3 <- lapply(mv, function(x) lapply(x, function(y) y[-1, ])) %>% 
+    #   lapply(function(x) lapply(x, function(y) matrixStats::colQuantiles(y, probs =  probs, drop = FALSE)))
+    # 
+    # ## Compare critical value and test statistic
+    # # For Mean
+    # decision_m <- mapply(function(x, y) abs(x) < y[, seq(2, length(.alpha)*2, by = 2), drop = FALSE],
+    #                      x = mv_o[[1]],
+    #                      y = critical_values_step3[[1]],
+    #                      SIMPLIFY = FALSE)
+    # # For Var
+    # decision_v <- mapply(function(x, y) abs(x) < y[, seq(2, length(.alpha)*2, by = 2), drop = FALSE],
+    #                      x = mv_o[[2]],
+    #                      y = critical_values_step3[[2]],
+    #                      SIMPLIFY = FALSE)
     
     ### Return output ==========================================================
     out <- list(
       "Step2" = list(
         "Test_statistic"     = c,
-        "Critical_value"     = critical_values_step2, 
-        "Decision"           = decision,
+        "P_value"            = padjusted_step2, 
+        "Decision"           = decision_step2,
         "Bootstrap_values"   = ref_dist
       ),
       "Step3" = list(
         "Mean" = list(
-          "Test_statistic"     = mv_o$Mean,
-          "Critical_value"     = critical_values_step3$Mean, 
-          "Decision"           = decision_m
+          "Test_statistic"     = teststat_mean,
+          "P_value"            = padjusted_mean, 
+          "Decision"           = decision_mean
         ),
         "Var" = list(
-          "Test_statistic"     = mv_o$Var,
-          "Critical_value"     = critical_values_step3$Var, 
-          "Decision"           = decision_v
+          "Test_statistic"     = teststat_var,
+          "P_value"            = padjusted_var, 
+          "Decision"           = decision_var
         )
       ),
       "Information" = list(
