@@ -8,6 +8,8 @@
 #'
 #' @param .alpha An integer or a numeric vector of significance levels. 
 #'   Defaults to `0.05`.
+#' @param .absolute Logical. Should the absolute HTMT values be returned? 
+#'   Defaults to `TRUE` .
 #' @param .approach_gcca Character string. The Kettenring approach to use for GCCA. One of 
 #' "*SUMCORR*", "*MAXVAR*", "*SSQCORR*", "*MINVAR*" or "*GENVAR*". Defaults to
 #' "*SUMCORR*".
@@ -27,14 +29,13 @@
 #'   Only use if you know what you are doing.
 #' @param .approach_mgd Character string or a vector of character strings. 
 #'   Approach used for the multi-group comparison. One of: "*all*", "*Klesel*", "*Chin*", 
-#'   "*Sarstedt*", "*Keil*, "*Nitzl*", or "*Henseler*". 
+#'   "*Sarstedt*", "*Keil*, "*Nitzl*", "*Henseler*", "*CI_para*", or "*CI_overlap*". 
 #'   Default to "*all*" in which case all approaches are computed (if possible).
-#'   Note that the output will be quite long in this case. 
 #' @param .approach_nl Character string. Approach used to estimate nonlinear
 #'   structural relationships. One of: "*sequential*" or "*replace*".
 #'   Defaults to "*sequential*".
 #' @param .approach_p_adjust Character string or a vector of character strings. 
-#' Approach used to adjust the p-value in multiple testing. 
+#' Approach used to adjust the p-value for multiple testing. 
 #' See the `methods` argument of \code{\link[stats:p.adjust]{stats::p.adjust()}} for a list of choices and
 #' their description. Defaults to "*none*".
 #' @param .approach_paths Character string. Approach used to estimate the
@@ -63,6 +64,7 @@
 #'   Defaults to `FALSE`.
 #' @param .ci A vector of character strings naming the confidence interval to compute.
 #'   For possible choices see [infer()].
+#' @param .ci_colnames Internal argument used by several print helper functions.
 #' @param .closed_form_ci Logical. Should a closed-form confidence interval be computed?
 #'   Defaults to `FALSE`.
 #' @param .conv_criterion Character string. The criterion to use for the convergence check.
@@ -78,6 +80,7 @@
 #'   of the data provided are: "`logical`", "`numeric`" ("`double`" or "`integer`"), 
 #'   "`factor`" ("`ordered`" and/or "`unordered`"), "`character`" (converted to factor),
 #'   or a mix of several types.
+#' @param .dependent Character string. The name of the dependent variable. Defaults to `NULL`. 
 #' @param .disattenuate Logical. Should composite/proxy correlations 
 #'   be disattenuated to yield consistent loadings and path estimates if at least
 #'   one of the construct is modeled as a common factor? Defaults to `TRUE`.
@@ -94,6 +97,7 @@
 #'   Dominant indicators may be specified for a subset of the constructs. 
 #'   Default to `NULL`.
 #' @param .E A (J x J) matrix of inner weights.
+#' @param .effect Internal argument used by helper printEffects().
 #' @param .estimate_structural Logical. Should the structural coefficients
 #'   be estimated? Defaults to `TRUE`.
 #' @param .eval_plan Character string. The evaluation plan to use. One of 
@@ -101,6 +105,10 @@
 #'   all available cores will be used. Defaults to "*sequential*".
 #' @param .first_resample A list containing the `.R` resamples based on the original
 #'   data obtained by resamplecSEMResults().
+#' @param .force Logical. Should .object be resampled even if it contains resamples
+#'   already?. Defaults to `FALSE`.
+#' @param .fit_measures Logical. (EXPERIMENTAL) Should additional fit measures 
+#'   be included? Defaults to `FALSE`. 
 #' @param .full_output Logical. Should the full output of summarize be printed.
 #'   Defaults to `TRUE`.
 #' @param .H The (N x J) matrix of construct scores.
@@ -116,6 +124,10 @@
 #' @param .id Character string or integer. A character string giving the name or 
 #'   an integer of the position of the column of `.data` whose levels are used
 #'   to split `.data` into groups. Defaults to `NULL`.
+#' @param .inference Logical. Should critical values be computed? Defaults to `FALSE`.
+#' @param .independent Character string. The name of the independent variable. Defaults to `NULL`.
+#' @param .independent_1 Character string. The name of the first independent variable. Defaults to `NULL`.
+#' @param .independent_2 Character string. The name of the second independent variable. Defaults to `NULL`.
 #' @param .instruments A named list of vectors of instruments. The names
 #'   of the list elements are the names of the dependent (LHS) constructs of the structural
 #'   equation whose explanatory variables are endogenous. The vectors
@@ -131,15 +143,13 @@
 #' @param .matrices A list of at least two matrices.
 #' @param .model A model in [lavaan model syntax][lavaan::model.syntax] 
 #'   or a [cSEMModel] list.
-#' @param .model_implied Logical. Should the RMS_theta be computed using the
-#'   model-implied construct correlation matrix (`TRUE`) or the construct correlation matrix
-#'   based on V(eta) = WSW' divided by the square root of the respective 
-#'   reliabilities (`FALSE`). Defaults to `FALSE`.
+#' @param .moderator Character string. The name of the moderator variable. Defaults to `NULL`. 
 #' @param .modes A vector giving the mode for each construct in the form `"name" = "mode"`. 
 #'   Only used internally. 
 #' @param .n Integer. The number of observations of the original data.
-#' @param .n_spotlights Integer. A numeric value giving the number of spotlights (= values of .z) 
-#'   between min(.z) and max(.z) to use. Defaults to `100`.
+#' @param .n_steps Integer. A numeric value giving the number of steps, e.g., in
+#' surface analysis or floodlight analysis the spotlights (= values of .moderator)
+#' between min(.moderator) and max(.moderator) to use. Defaults to `100`.
 #' @param .normality Logical. Should joint normality of 
 #' \eqn{[\eta_{1:p}; \zeta; \epsilon]}{[\eta_(1:p); \zeta; \epsilon]}
 #'  be assumed in the nonlinear model? See \insertCite{Dijkstra2014}{cSEM} for details.
@@ -156,8 +166,8 @@
 #' @param .P A (J x J) construct variance-covariance matrix (possibly disattenuated).
 #' @param .parameters_to_compare A model in [lavaan model syntax][lavaan::model.syntax] indicating which 
 #'   parameters (i.e, path (`~`), loadings (`=~`), weights (`<~`), or correlations (`~~`)) should be
-#'   compared across groups. Defaults to `NULL` in which case all parameters of the 
-#'   originally specified model are compared.
+#'   compared across groups. Defaults to `NULL` in which case all weights, loadings and 
+#'   path coefficients of the originally specified model are compared.
 #' @param .PLS_approach_cf Character string. Approach used to obtain the correction
 #'   factors for PLSc. One of: "*dist_squared_euclid*", "*dist_euclid_weighted*",
 #'   "*fisher_transformed*", "*mean_arithmetic*", "*mean_geometric*", "*mean_harmonic*",
@@ -233,6 +243,8 @@
 #' "*individual_reestimate*", "*construct_reestimate*". Defaults to "*none*".
 #' @param .stage Character string. The stage the model is needed for.
 #'   One of "*first*" or "*second*". Defaults to "*first*".
+#' @param .standardized Logical. Should standardized scores be returned? Defaults
+#'   to `TRUE`.
 #' @param .starting_values A named list of vectors where the
 #'   list names are the construct names whose indicator weights the user
 #'   wishes to set. The vectors must be named vectors of `"indicator_name" = value` 
@@ -242,6 +254,13 @@
 #'   training data.
 #' @param .tolerance Double. The tolerance criterion for convergence. 
 #'   Defaults to `1e-05`.
+#' @param .type_ci Character string. It indicates which confidence interval should be calculated. 
+#' For possible choices, see the `.quantity` argument of the \code{\link{infer}} function. 
+#' In the test_mgd function default is to "*CI_percentile*".
+#' @param .type Character string. Which fitting function should the GFI be based 
+#'   on? One of *"ML"* for the maximum likelihood fitting function or *"ULS"* for the
+#'   unweighted least squares fitting function (same as the squared Euclidian distance). 
+#'   Defaults to *"ML"*.
 #' @param .type_vcv Character string. Which model-implied correlation 
 #'  matrix is calculated?
 #'  One of "*indicator*" or "*construct*". Defaults to "*indicator*".   
@@ -259,16 +278,14 @@
 #' @param .vector1 A vector of numeric values.
 #' @param .vector2 A vector of numeric values.
 #' @param .W A (J x K) matrix of weights.
+#' @param .what Internal argument used by several print helper functions.
 #' @param .W_new A (J x K) matrix of weights.
 #' @param .W_old A (J x K) matrix of weights.
 #' @param .weighted Logical. Should estimation be based on a score that uses 
 #'   the weights of the weight approach used to obtain `.object`?. Defaults to `FALSE`.
-#' @param .x Character string. The name of the moderator variable. Defaults to `NULL`. 
 #' @param .X A matrix of processed data (scaled, cleaned and ordered).
 #' @param .X_cleaned A data.frame of processed data (cleaned and ordered). Note: `X_cleaned`
 #'   may not be scaled!
-#' @param .y Character string. The name of the dependent variable. Defaults to `NULL`. 
-#' @param .z Character string. The name of the independent variable. Defaults to `NULL`.
 #'
 #' @name csem_arguments
 #' @aliases cSEMArguments
@@ -328,12 +345,15 @@ args_csem_dotdotdot <- function(
 #' accepted by a subset of the functions called by `assess()`. The following
 #' list shows which argument is passed to which (internal) function:
 #' \describe{
-#' \item{.alpha}{Accepted by/Passed down to: [calculateRhoT()]}
+#' \item{.absolute}{Accepted by/Passed down to: [calculateHTMT()]}
+#' \item{.alpha}{Accepted by/Passed down to: [calculateRhoT()] and [calculateHTMT()]}
 #' \item{.closed_form_ci}{Accepted by/Passed down to: [calculateRhoT()]}
-#' \item{.model_implied}{Accepted by/Passed down to: [calculateRMSTheta()]}
+#' \item{.handle_inadmissibles}{Accepted by/Passed down to: [calculateHTMT()]}
 #' \item{.null_model}{Accepted by/Passed down to: [calculateDf()]}
+#' \item{.R}{Accepted by/Passed down to: [calculateHTMT()]}
 #' \item{.saturated}{Accepted by/Passed down to: [calculateSRMR()], 
 #'   [calculateDG()], [calculateDL()], [calculateDML()]and subsequently [fit()].}
+#' \item{.seed}{Accepted by/Passed down to: [calculateHTMT()]}
 #' \item{.type_vcv}{Accepted by/Passed down to: [calculateSRMR()], 
 #'   [calculateDG()], [calculateDL()], [calculateDML()] and subsequently [fit()].}
 #' }
@@ -343,11 +363,15 @@ args_csem_dotdotdot <- function(
 #' @keywords internal
 
 args_assess_dotdotdot <- function(
+  .absolute            = TRUE,
   .alpha               = 0.05,
   .closed_form_ci      = FALSE,
-  .model_implied       = FALSE,
+  .handle_inadmissibles= c("drop", "ignore", "replace"),
+  .inference           = FALSE,
   .null_model          = FALSE,
+  .R                   = 499,
   .saturated           = FALSE,
+  .seed                = NULL,
   .type_vcv            = "indicator"
 ) {NULL}
   
@@ -373,10 +397,11 @@ args_default <- function(.choices = FALSE) {
   
   args <- list(
     .alpha                   = 0.05,
+    .absolute                = TRUE,
     .approach_gcca           = c("SUMCORR", "MAXVAR", "SSQCORR", "MINVAR", "GENVAR"),
     .approach_2ndorder       = c("2stage", "mixed"),
     .approach_alpha_adjust   = c("none", "bonferroni"),
-    .approach_mgd            = c("all", "Klesel", "Chin", "Sarstedt", "Keil", "Nitzl", "Henseler"),
+    .approach_mgd            = c("all", "Klesel", "Chin", "Sarstedt", "Keil", "Nitzl", "Henseler","CI_para","CI_overlap"),
     .approach_nl             = c("sequential", "replace"),
     .approach_p_adjust       = "none",
     .approach_paths          = c("OLS", "2SLS"),
@@ -390,31 +415,40 @@ args_default <- function(.choices = FALSE) {
     .choices                 = FALSE,
     .ci                      = c("CI_standard_z", "CI_standard_t", "CI_percentile", 
                                  "CI_basic", "CI_bc", "CI_bca", "CI_t_interval"),
+    .ci_colnames             = NULL,
     .closed_form_ci          = FALSE, 
     .csem_model              = NULL,
     .csem_resample           = NULL,
     .cv_folds                = 10,
     .data                    = NULL,
+    .dependent               = NULL,
     .disattenuate            = TRUE,
     .dist                    = c("z", "t"),
     .distance                = c("geodesic", "squared_euclidian"),
     .df                      = c("type1", "type2"),
     .E                       = NULL,
+    .effect                  = NULL,
     .eval_plan               = c("sequential", "multiprocess"),
+    .force                   = FALSE,
+    .fit_measures            = FALSE,
     .first_resample          = NULL,
     .full_output             = TRUE,
     .handle_inadmissibles    = c("drop", "ignore", "replace"),
     .H                       = NULL,
     .id                      = NULL,
+    .inference               = FALSE,
+    .independent             = NULL,
+    .independent_1           = NULL,
+    .independent_2           = NULL,
     .instruments             = NULL,
     .listMatrices            = NULL, 
     .matrix1                 = NULL,
     .matrix2                 = NULL,
     .matrices                = NULL,
     .model                   = NULL,
-    .model_implied           = FALSE,
+    .moderator               = NULL,
     .modes                   = NULL,
-    .n_spotlights            = 100,
+    .n_steps                 = 100,
     .normality               = FALSE,
     .nr_comparisons          = NULL,
     .null_model              = FALSE,
@@ -423,13 +457,16 @@ args_default <- function(.choices = FALSE) {
     .P                       = NULL,
     .parameters_to_compare   = NULL,
     .probs                   = NULL,
-    .quality_criterion       = c("all", "ave", "rho_C", "rho_C_weighted", "cronbachs_alpha", 
+    .quality_criterion       = c("all", "ave", "rho_C", "rho_C_mm", "rho_C_weighted", 
+                                 "rho_C_weighted_mm", "cronbachs_alpha", 
                                  "cronbachs_alpha_weighted", "dg", "dl", "dml", "df",
-                                 "esize", "cfi", "gfi", "ifi", "nfi", "nnfi", 
+                                 "effects", "f2", "chi_square", "chi_square_df",
+                                 "cfi", "gfi", "ifi", "nfi", "nnfi", 
+                                 "reliability",
                                  "rmsea", "rms_theta", "srmr",
                                  "gof", "htmt", "r2", "r2_adj",
                                  "rho_T", "rho_T_weighted", "vif", 
-                                 "vifmodeb",  "fl_criterionB"),
+                                 "vifmodeB",  "fl_criterion"),
     
     .quantity                = c("all", "mean", "sd", "bias", "CI_standard_z", "CI_standard_t",
                                  "CI_percentile", "CI_basic", "CI_bc", "CI_bca", "CI_t_intervall"),
@@ -451,15 +488,20 @@ args_default <- function(.choices = FALSE) {
     .sign_change_option      = c("none", "individual", "individual_reestimate",
                                  "construct_reestimate"),
     .stage                   = c("first", "second"),
+    .standardized            = TRUE,
     .starting_values         = NULL,
     .terms                   = NULL,
     .test_data               = NULL,
+    .type                    = c("ML", "ULS"),
     .type_vcv                = c("indicator", "construct"),
+    .type_ci                 = c("CI_percentile","CI_standard_z","CI_standard_t",
+                                 "CI_basic","CI_bc", "CI_bca"),
     .user_funs               = NULL,
     .vcv_asymptotic          = c(FALSE, TRUE),
     .verbose                 = TRUE,
     .W                       = NULL,
     .weighted                = FALSE,
+    .what                    = NULL,
     .x                       = NULL,
     .X                       = NULL,
     .X_cleaned               = NULL,
